pub struct AVMMemoryStats {
pub memory_size: usize,
pub total_memory_limit: Option<u64>,
pub allocation_rejects: Option<u32>,
}Expand description
Return statistic of AVM server Wasm module heap footprint.
Fields
memory_size: usizeSize of currently used linear memory in bytes. Please note that linear memory contains not only heap, but globals, shadow stack and so on.
total_memory_limit: Option<u64>Possibly set max memory size for AVM server.
allocation_rejects: Option<u32>Number of allocations rejected due to memory limit. May be not recorded by some backends in Marine.